@@ -107,8 +107,16 @@ class APIFixture(fixture.GabbiFixture):
 
         os.environ['RP_UUID'] = uuidutils.generate_uuid()
         os.environ['RP_NAME'] = uuidutils.generate_uuid()
+        os.environ['RP_UUID1'] = uuidutils.generate_uuid()
+        os.environ['RP_NAME1'] = uuidutils.generate_uuid()
+        os.environ['RP_UUID2'] = uuidutils.generate_uuid()
+        os.environ['RP_NAME2'] = uuidutils.generate_uuid()
         os.environ['CUSTOM_RES_CLASS'] = 'CUSTOM_IRON_NFV'
+        os.environ['CUSTOM_RES_CLASS1'] = 'CUSTOM_IRON_NFV1'
+        os.environ['CUSTOM_RES_CLASS2'] = 'CUSTOM_IRON_NFV2'
         os.environ['PROJECT_ID'] = uuidutils.generate_uuid()
+        os.environ['ADMIN_PROJECT_ID'] = uuidutils.generate_uuid()
+        os.environ['SERVICE_PROJECT_ID'] = uuidutils.generate_uuid()
         os.environ['USER_ID'] = uuidutils.generate_uuid()
         os.environ['PROJECT_ID_ALT'] = uuidutils.generate_uuid()
         os.environ['USER_ID_ALT'] = uuidutils.generate_uuid()
@@ -148,6 +156,7 @@ class AllocationFixture(APIFixture):
                 |      DISK_GB:2048      |
                 +------------------------+
     """
+
     def start_fixture(self):
         super(AllocationFixture, self).start_fixture()
 
@@ -588,6 +597,7 @@ class DeepNUMANetworkFixture(NUMANetworkFixture):
     parents and grandparents of the compute nodes. This is to exercise
     same_subtree in a more complete fashion.
     """
+
     def make_entities(self):
         """Create parents and grandparents for cn1 and cn2. They will be fully
         populated by the superclass, NUMANetworkFixture.
@@ -606,6 +616,7 @@ class NonSharedStorageFixture(APIFixture):
     """An APIFixture that has three compute nodes with local storage that do
     not use shared storage.
     """
+
     def start_fixture(self):
         super(NonSharedStorageFixture, self).start_fixture()
 
@@ -676,6 +687,7 @@ class GranularFixture(APIFixture):
 |traits: MISC_SHARES... +.........+
 +=======================+
     """
+
     def start_fixture(self):
         super(GranularFixture, self).start_fixture()
 
